@@ -14,3 +14,12 @@ def checks(*funcs: typing.Callable[[Context], typing.Union[bool, typing.Awaitabl
                 maybe_cmd._checks = [*funcs]
         return maybe_cmd
     return wrap
+
+
+async def __is_owner(ctx: Context):
+    return await ctx.bot.is_owner(ctx)
+
+
+def is_owner():
+    return checks(__is_owner)
+
